/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.common.api.view;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadataView;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;

public interface ICommonView extends ISharedMetadataView {

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs}
     *         annotation.
     */
    List<IJEjbEJB> getJEjbEJBs();

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    List<IJAnnotationResource> getJAnnotationResources();

    /**
     * @return jAnnotationSqlDataSourceDefinitions list representing &#64;{@link javax.annotation.sql.DataSourceDefinitions} annotation.
     */
    List<IJAnnotationSqlDataSourceDefinition> getJAnnotationSqlDataSourceDefinitions();

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts();

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits();

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs();

    /**
     * @return the name of the security-role of the run-as element.
     */
    String getRunAs();


    /**
     * Returns the ManagedBean name or null if class is not annotated with @ManagedBean
     *
     * @return the ManagedBean name or null.
     */
    String getManagedBeanName();

    /**
     * Returns true if class is not annotated with @ManagedBean
     * @return true if class is not annotated with @ManagedBean
     */
     boolean isManagedBean();
}
